
# Type: identifier


true means that this slot is the subject of a set of assertions.  Identifiers do not appear as predicates in the model

URI: [meta:identifier](https://w3id.org/biolink/biolinkml/meta/identifier)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | identifier is inherited |
|  | | identifier slots are always required |
|  | | a given domain can have at most one identifier |

